@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Dict, List
+from typing import Any, Dict, List
 
 from .literals import (
     GettablePolicyStateValuesType,
@@ -22,6 +22,7 @@ from .literals import (
     ResourceLocationValuesType,
     ResourceTypeValuesType,
     RetentionIntervalUnitValuesType,
+    SettablePolicyStateValuesType,
 )
 
 if sys.version_info >= (3, 8):
@@ -36,26 +37,35 @@ else:
 
 __all__ = (
     "ActionTypeDef",
+    "CreateLifecyclePolicyRequestRequestTypeDef",
     "CreateLifecyclePolicyResponseTypeDef",
     "CreateRuleTypeDef",
     "CrossRegionCopyActionTypeDef",
     "CrossRegionCopyRetainRuleTypeDef",
     "CrossRegionCopyRuleTypeDef",
+    "DeleteLifecyclePolicyRequestRequestTypeDef",
     "EncryptionConfigurationTypeDef",
     "EventParametersTypeDef",
     "EventSourceTypeDef",
     "FastRestoreRuleTypeDef",
+    "GetLifecyclePoliciesRequestRequestTypeDef",
     "GetLifecyclePoliciesResponseTypeDef",
+    "GetLifecyclePolicyRequestRequestTypeDef",
     "GetLifecyclePolicyResponseTypeDef",
     "LifecyclePolicySummaryTypeDef",
     "LifecyclePolicyTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ParametersTypeDef",
     "PolicyDetailsTypeDef",
+    "ResponseMetadataTypeDef",
     "RetainRuleTypeDef",
     "ScheduleTypeDef",
     "ShareRuleTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateLifecyclePolicyRequestRequestTypeDef",
 )
 
 ActionTypeDef = TypedDict(
@@ -66,12 +76,37 @@ ActionTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateLifecyclePolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLifecyclePolicyRequestRequestTypeDef",
+    {
+        "ExecutionRoleArn": str,
+        "Description": str,
+        "State": SettablePolicyStateValuesType,
+        "PolicyDetails": "PolicyDetailsTypeDef",
+    },
+)
+_OptionalCreateLifecyclePolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLifecyclePolicyRequestRequestTypeDef",
+    {
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateLifecyclePolicyRequestRequestTypeDef(
+    _RequiredCreateLifecyclePolicyRequestRequestTypeDef,
+    _OptionalCreateLifecyclePolicyRequestRequestTypeDef,
+):
+    pass
+
+
 CreateLifecyclePolicyResponseTypeDef = TypedDict(
     "CreateLifecyclePolicyResponseTypeDef",
     {
         "PolicyId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 CreateRuleTypeDef = TypedDict(
@@ -142,6 +177,13 @@ class CrossRegionCopyRuleTypeDef(
     pass
 
 
+DeleteLifecyclePolicyRequestRequestTypeDef = TypedDict(
+    "DeleteLifecyclePolicyRequestRequestTypeDef",
+    {
+        "PolicyId": str,
+    },
+)
+
 _RequiredEncryptionConfigurationTypeDef = TypedDict(
     "_RequiredEncryptionConfigurationTypeDef",
     {
@@ -212,20 +254,39 @@ class FastRestoreRuleTypeDef(_RequiredFastRestoreRuleTypeDef, _OptionalFastResto
     pass
 
 
+GetLifecyclePoliciesRequestRequestTypeDef = TypedDict(
+    "GetLifecyclePoliciesRequestRequestTypeDef",
+    {
+        "PolicyIds": List[str],
+        "State": GettablePolicyStateValuesType,
+        "ResourceTypes": List[ResourceTypeValuesType],
+        "TargetTags": List[str],
+        "TagsToAdd": List[str],
+    },
+    total=False,
+)
+
 GetLifecyclePoliciesResponseTypeDef = TypedDict(
     "GetLifecyclePoliciesResponseTypeDef",
     {
         "Policies": List["LifecyclePolicySummaryTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetLifecyclePolicyRequestRequestTypeDef = TypedDict(
+    "GetLifecyclePolicyRequestRequestTypeDef",
+    {
+        "PolicyId": str,
     },
-    total=False,
 )
 
 GetLifecyclePolicyResponseTypeDef = TypedDict(
     "GetLifecyclePolicyResponseTypeDef",
     {
         "Policy": "LifecyclePolicyTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 LifecyclePolicySummaryTypeDef = TypedDict(
@@ -257,12 +318,19 @@ LifecyclePolicyTypeDef = TypedDict(
     total=False,
 )
 
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
     {
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ParametersTypeDef = TypedDict(
@@ -289,6 +357,17 @@ PolicyDetailsTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 RetainRuleTypeDef = TypedDict(
     "RetainRuleTypeDef",
     {
@@ -335,6 +414,14 @@ class ShareRuleTypeDef(_RequiredShareRuleTypeDef, _OptionalShareRuleTypeDef):
     pass
 
 
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "Tags": Dict[str, str],
+    },
+)
+
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -342,3 +429,35 @@ TagTypeDef = TypedDict(
         "Value": str,
     },
 )
+
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "TagKeys": List[str],
+    },
+)
+
+_RequiredUpdateLifecyclePolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateLifecyclePolicyRequestRequestTypeDef",
+    {
+        "PolicyId": str,
+    },
+)
+_OptionalUpdateLifecyclePolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateLifecyclePolicyRequestRequestTypeDef",
+    {
+        "ExecutionRoleArn": str,
+        "State": SettablePolicyStateValuesType,
+        "Description": str,
+        "PolicyDetails": "PolicyDetailsTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateLifecyclePolicyRequestRequestTypeDef(
+    _RequiredUpdateLifecyclePolicyRequestRequestTypeDef,
+    _OptionalUpdateLifecyclePolicyRequestRequestTypeDef,
+):
+    pass
